import os, simplejson, settings, time



class ThermometerNotFound(ValueError):
    pass


class Thermometer():
    name = None
    path = None

    def __init__(self, name):
        self.name = name
        self._build_path()

    def _build_path(self, ):
        self.path = os.path.join(settings.BASE_PATH, self.name, settings.TAIL_PATH)
        if not os.path.isfile(self.path):
            raise ThermometerNotFound("Thermometer with name %s not found" % self.name)


    def _read_raw(self, ):
        f = open(self.path, 'r')
        lines = f.readlines()
	f.close()
	return lines

    def read(self):
	lines = self._read_raw()
	while lines[0].strip()[-3:] != 'YES':
	    time.sleep(0.2)
	    lines = self._read_raw()
	equals_pos = lines[1].find('t=')
	if equals_pos != -1:
	    temp_string = lines[1][equals_pos+2:]

	temp_c = float(temp_string) / 1000.0
	temp_f = temp_c * 9.0 / 5.0 + 32.0
	return {"celsius": float(temp_c), "fahrenheit": float(temp_f)}

    def to_json(self):
	return simplejson.dumps({"name": self.name, "temperature": self.read()})


def get_thermometers():
    therms = {}
    for dirname, dirnames, filenames in os.walk('/sys/bus/w1/devices/'):
	for subdirname in dirnames:
	    if not subdirname.startswith("28-"):
		continue

	    therms[subdirname] = Thermometer(subdirname)
    return therms


def read_temperatures(thermometer=None):
    therms = get_thermometers()
    if thermometer:
	return {thermometer: therms[thermometer].read()}

    temps = {}
    for thermometer in therms:
	temps[thermometer] = therms[thermometer].read()
    return temps







from django.core.management.base import BaseCommand, CommandError
from django_thermostat.rules import evaluate
from time import localtime, strftime


class Command(BaseCommand):
    args = ''
    help = 'Read temperature from the DS18B20 termometers'

    def handle(self, *args, **options):
        pass



from django.http import HttpResponseBadRequest, HttpResponse
import simplejson
from temperature import read_temperatures, get_thermometers, ThermometerNotFound


def list_thermometers(request):
    if request.method != "GET":
        response = HttpResponseBadRequest(
            content=simplejson.dumps({"errors": ["Only GET method allowed", ]}),
            content_type="application/json")
        response["Cache-Control"] = 'no-cache'
        return response

    temperatures = None
    if "temperatures" in request.GET and request.GET["temperatures"] not in (None, ""):
        temperatures = request.GET["temperatures"]

    if temperatures is None:
        response = HttpResponse(
            content=simplejson.dumps([x.name for x in get_thermometers()]),
            content_type="application/json")
    else:
        response = HttpResponse(
            content=simplejson.dumps(read_temperatures()),
            content_type="application/json",
        )
    response['Cache-Control'] = 'no-cache'
    return response


def thermometer(request, thermometer):
    if request.method != "GET":
        response = HttpResponseBadRequest(
            content=simplejson.dumps({"errors": ["Only GET method allowed", ]}),
            content_type="application/json")
        response["Cache-Control"] = 'no-cache'
        return response
    try:

        response = HttpResponse(
            content=simplejson.dumps(read_temperatures(thermometer)),
            content_type="application/json",
        )
        response["Cache-Control"] = "no-cache"
        return response

    except ThermometerNotFound:
        response = HttpResponseBadRequest(
            content=simplejson.dumps({"errors": ["Themometer %s not found" % thermometer, ]}),
            content_type="application/json")
        response["Cache-Control"] = 'no-cache'
        return response




from django.conf.urls import patterns, include, url

# Uncomment the next two lines to enable the admin:
#from django.contrib import admin
#admin.autodiscover()

urlpatterns = patterns('',
    url(r'^thermometers/?$', "django_thermometer.views.list_thermometers", name="list_thermometers"),
    url(r'^thermometer/(\w+)$', "django_thermometer.views.thermometer", name="thermometer"),
)
